# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.api_key_auth import ApiKeyAuth
from ...types.general_auth import GeneralAuth

Authdata = typing.Union[ApiKeyAuth, GeneralAuth]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.delete_user_response import DeleteUserResponse
from ..types.get_server_instances_response import GetServerInstancesResponse
from .raw_client import AsyncRawUserClient, RawUserClient


class UserClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawUserClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawUserClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawUserClient
        """
        return self._raw_client

    def get_server_instances_by_user(
        self,
        *,
        user_id: str,
        platform_name: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetServerInstancesResponse:
        """
        Get all MCP server instances information by user ID and platform name.

        Parameters
        ----------
        user_id : str
            The external user ID

        platform_name : typing.Optional[str]
            The platform name (optional)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetServerInstancesResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.user.get_server_instances_by_user(
            user_id="user_id",
        )
        """
        _response = self._raw_client.get_server_instances_by_user(
            user_id=user_id, platform_name=platform_name, request_options=request_options
        )
        return _response.data

    def delete_user_by_user_id(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteUserResponse:
        """
        Delete a user and all associated data by user_id.
        Users cannot delete their own accounts.
        This operation will permanently remove all user data.

        Parameters
        ----------
        user_id : str
            The identifier for the user to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteUserResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.user.delete_user_by_user_id(
            user_id="user_id",
        )
        """
        _response = self._raw_client.delete_user_by_user_id(user_id, request_options=request_options)
        return _response.data


class AsyncUserClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawUserClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawUserClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawUserClient
        """
        return self._raw_client

    async def get_server_instances_by_user(
        self,
        *,
        user_id: str,
        platform_name: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetServerInstancesResponse:
        """
        Get all MCP server instances information by user ID and platform name.

        Parameters
        ----------
        user_id : str
            The external user ID

        platform_name : typing.Optional[str]
            The platform name (optional)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetServerInstancesResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.user.get_server_instances_by_user(
                user_id="user_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_server_instances_by_user(
            user_id=user_id, platform_name=platform_name, request_options=request_options
        )
        return _response.data

    async def delete_user_by_user_id(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteUserResponse:
        """
        Delete a user and all associated data by user_id.
        Users cannot delete their own accounts.
        This operation will permanently remove all user data.

        Parameters
        ----------
        user_id : str
            The identifier for the user to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteUserResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.user.delete_user_by_user_id(
                user_id="user_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_user_by_user_id(user_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .api_key_auth import ApiKeyAuth
from .calcom_o_auth_error_response import CalcomOAuthErrorResponse
from .calcom_o_auth_success_response import CalcomOAuthSuccessResponse
from .call_tool_response import CallToolResponse
from .call_tool_result import CallToolResult
from .connection_type import ConnectionType
from .create_self_hosted_server_response import CreateSelfHostedServerResponse
from .create_server_response import CreateServerResponse
from .delete_user_response import DeleteUserResponse
from .extended_mcp_server import ExtendedMcpServer
from .external_server_info import ExternalServerInfo
from .external_server_request import ExternalServerRequest
from .general_auth import GeneralAuth
from .get_auth_data_response import GetAuthDataResponse
from .get_instance_response import GetInstanceResponse
from .get_mcp_servers_response import GetMcpServersResponse
from .get_o_auth_url_response import GetOAuthUrlResponse
from .get_server_instances_response import GetServerInstancesResponse
from .http_validation_error import HttpValidationError
from .list_tools_response import ListToolsResponse
from .mcp_server import McpServer
from .mcp_server_name import McpServerName
from .o_auth_server_name import OAuthServerName
from .server_tool import ServerTool
from .status_response import StatusResponse
from .strata_add_servers_response import StrataAddServersResponse
from .strata_create_response import StrataCreateResponse
from .strata_delete_servers_response import StrataDeleteServersResponse
from .strata_get_response import StrataGetResponse
from .tool_format import ToolFormat
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .white_labeling_response import WhiteLabelingResponse

__all__ = [
    "ApiKeyAuth",
    "CalcomOAuthErrorResponse",
    "CalcomOAuthSuccessResponse",
    "CallToolResponse",
    "CallToolResult",
    "ConnectionType",
    "CreateSelfHostedServerResponse",
    "CreateServerResponse",
    "DeleteUserResponse",
    "ExtendedMcpServer",
    "ExternalServerInfo",
    "ExternalServerRequest",
    "GeneralAuth",
    "GetAuthDataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetOAuthUrlResponse",
    "GetServerInstancesResponse",
    "HttpValidationError",
    "ListToolsResponse",
    "McpServer",
    "McpServerName",
    "OAuthServerName",
    "ServerTool",
    "StatusResponse",
    "StrataAddServersResponse",
    "StrataCreateResponse",
    "StrataDeleteServersResponse",
    "StrataGetResponse",
    "ToolFormat",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import Authdata, DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem, Servers

__all__ = ["Authdata", "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem", "Servers"]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ConnectionType(str, enum.Enum):
    SSE = "SSE"
    STREAMABLE_HTTP = "StreamableHttp"

    def visit(self, sse: typing.Callable[[], T_Result], streamable_http: typing.Callable[[], T_Result]) -> T_Result:
        if self is ConnectionType.SSE:
            return sse()
        if self is ConnectionType.STREAMABLE_HTTP:
            return streamable_http()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OAuthServerName(str, enum.Enum):
    AIRTABLE = "Airtable"
    ASANA = "Asana"
    ATTIO = "Attio"
    BOX = "Box"
    CAL_COM = "Cal.com"
    CANVA = "Canva"
    CLICK_UP = "ClickUp"
    CLOSE = "Close"
    CONFLUENCE = "Confluence"
    DIALPAD = "Dialpad"
    DOCU_SIGN = "DocuSign"
    DROPBOX = "Dropbox"
    FIGMA = "Figma"
    GIT_HUB = "GitHub"
    GIT_LAB = "GitLab"
    GMAIL = "Gmail"
    GOOGLE_CALENDAR = "Google Calendar"
    GOOGLE_DOCS = "Google Docs"
    GOOGLE_DRIVE = "Google Drive"
    GOOGLE_SHEETS = "Google Sheets"
    HUB_SPOT = "HubSpot"
    JIRA = "Jira"
    KLAVIYO = "Klaviyo"
    LINEAR = "Linear"
    LINKED_IN = "LinkedIn"
    MONDAY = "Monday"
    MONEYBIRD = "Moneybird"
    NOTION = "Notion"
    ONEDRIVE = "Onedrive"
    PAGER_DUTY = "PagerDuty"
    PIPEDRIVE = "Pipedrive"
    QUICK_BOOKS = "QuickBooks"
    SALESFORCE = "Salesforce"
    SHOPIFY = "Shopify"
    SLACK = "Slack"
    STRIPE = "Stripe"
    SUPABASE = "Supabase"
    VERCEL = "Vercel"
    WORD_PRESS = "WordPress"
    XERO = "Xero"
    ZENDESK = "Zendesk"

    def visit(
        self,
        airtable: typing.Callable[[], T_Result],
        asana: typing.Callable[[], T_Result],
        attio: typing.Callable[[], T_Result],
        box: typing.Callable[[], T_Result],
        cal_com: typing.Callable[[], T_Result],
        canva: typing.Callable[[], T_Result],
        click_up: typing.Callable[[], T_Result],
        close: typing.Callable[[], T_Result],
        confluence: typing.Callable[[], T_Result],
        dialpad: typing.Callable[[], T_Result],
        docu_sign: typing.Callable[[], T_Result],
        dropbox: typing.Callable[[], T_Result],
        figma: typing.Callable[[], T_Result],
        git_hub: typing.Callable[[], T_Result],
        git_lab: typing.Callable[[], T_Result],
        gmail: typing.Callable[[], T_Result],
        google_calendar: typing.Callable[[], T_Result],
        google_docs: typing.Callable[[], T_Result],
        google_drive: typing.Callable[[], T_Result],
        google_sheets: typing.Callable[[], T_Result],
        hub_spot: typing.Callable[[], T_Result],
        jira: typing.Callable[[], T_Result],
        klaviyo: typing.Callable[[], T_Result],
        linear: typing.Callable[[], T_Result],
        linked_in: typing.Callable[[], T_Result],
        monday: typing.Callable[[], T_Result],
        moneybird: typing.Callable[[], T_Result],
        notion: typing.Callable[[], T_Result],
        onedrive: typing.Callable[[], T_Result],
        pager_duty: typing.Callable[[], T_Result],
        pipedrive: typing.Callable[[], T_Result],
        quick_books: typing.Callable[[], T_Result],
        salesforce: typing.Callable[[], T_Result],
        shopify: typing.Callable[[], T_Result],
        slack: typing.Callable[[], T_Result],
        stripe: typing.Callable[[], T_Result],
        supabase: typing.Callable[[], T_Result],
        vercel: typing.Callable[[], T_Result],
        word_press: typing.Callable[[], T_Result],
        xero: typing.Callable[[], T_Result],
        zendesk: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is OAuthServerName.AIRTABLE:
            return airtable()
        if self is OAuthServerName.ASANA:
            return asana()
        if self is OAuthServerName.ATTIO:
            return attio()
        if self is OAuthServerName.BOX:
            return box()
        if self is OAuthServerName.CAL_COM:
            return cal_com()
        if self is OAuthServerName.CANVA:
            return canva()
        if self is OAuthServerName.CLICK_UP:
            return click_up()
        if self is OAuthServerName.CLOSE:
            return close()
        if self is OAuthServerName.CONFLUENCE:
            return confluence()
        if self is OAuthServerName.DIALPAD:
            return dialpad()
        if self is OAuthServerName.DOCU_SIGN:
            return docu_sign()
        if self is OAuthServerName.DROPBOX:
            return dropbox()
        if self is OAuthServerName.FIGMA:
            return figma()
        if self is OAuthServerName.GIT_HUB:
            return git_hub()
        if self is OAuthServerName.GIT_LAB:
            return git_lab()
        if self is OAuthServerName.GMAIL:
            return gmail()
        if self is OAuthServerName.GOOGLE_CALENDAR:
            return google_calendar()
        if self is OAuthServerName.GOOGLE_DOCS:
            return google_docs()
        if self is OAuthServerName.GOOGLE_DRIVE:
            return google_drive()
        if self is OAuthServerName.GOOGLE_SHEETS:
            return google_sheets()
        if self is OAuthServerName.HUB_SPOT:
            return hub_spot()
        if self is OAuthServerName.JIRA:
            return jira()
        if self is OAuthServerName.KLAVIYO:
            return klaviyo()
        if self is OAuthServerName.LINEAR:
            return linear()
        if self is OAuthServerName.LINKED_IN:
            return linked_in()
        if self is OAuthServerName.MONDAY:
            return monday()
        if self is OAuthServerName.MONEYBIRD:
            return moneybird()
        if self is OAuthServerName.NOTION:
            return notion()
        if self is OAuthServerName.ONEDRIVE:
            return onedrive()
        if self is OAuthServerName.PAGER_DUTY:
            return pager_duty()
        if self is OAuthServerName.PIPEDRIVE:
            return pipedrive()
        if self is OAuthServerName.QUICK_BOOKS:
            return quick_books()
        if self is OAuthServerName.SALESFORCE:
            return salesforce()
        if self is OAuthServerName.SHOPIFY:
            return shopify()
        if self is OAuthServerName.SLACK:
            return slack()
        if self is OAuthServerName.STRIPE:
            return stripe()
        if self is OAuthServerName.SUPABASE:
            return supabase()
        if self is OAuthServerName.VERCEL:
            return vercel()
        if self is OAuthServerName.WORD_PRESS:
            return word_press()
        if self is OAuthServerName.XERO:
            return xero()
        if self is OAuthServerName.ZENDESK:
            return zendesk()



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError


class RawNotionOauthClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def authorize_notion(
        self,
        *,
        instance_id: str,
        client_id: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        redirect_url: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.Optional[typing.Any]]:
        """
        Start Notion OAuth flow

        Parameters:
        - instance_id: Identifier for the instance requesting authorization
        - client_id: Optional client ID for white labeling
        - scope: Optional scopes to request (comma-separated)
        - redirect_url: Optional URL to redirect to after authorization completes

        Parameters
        ----------
        instance_id : str
            Unique identifier for the client instance requesting authorization

        client_id : typing.Optional[str]
            Client ID for white labeling, if not provided will use default credentials

        scope : typing.Optional[str]
            Optional OAuth scopes to request (comma-separated string)

        redirect_url : typing.Optional[str]
            Optional URL to redirect to after authorization completes

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.Optional[typing.Any]]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "oauth/notion/authorize",
            method="GET",
            params={
                "instance_id": instance_id,
                "client_id": client_id,
                "scope": scope,
                "redirect_url": redirect_url,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return HttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Optional[typing.Any],
                    parse_obj_as(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawNotionOauthClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def authorize_notion(
        self,
        *,
        instance_id: str,
        client_id: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        redirect_url: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.Optional[typing.Any]]:
        """
        Start Notion OAuth flow

        Parameters:
        - instance_id: Identifier for the instance requesting authorization
        - client_id: Optional client ID for white labeling
        - scope: Optional scopes to request (comma-separated)
        - redirect_url: Optional URL to redirect to after authorization completes

        Parameters
        ----------
        instance_id : str
            Unique identifier for the client instance requesting authorization

        client_id : typing.Optional[str]
            Client ID for white labeling, if not provided will use default credentials

        scope : typing.Optional[str]
            Optional OAuth scopes to request (comma-separated string)

        redirect_url : typing.Optional[str]
            Optional URL to redirect to after authorization completes

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.Optional[typing.Any]]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "oauth/notion/authorize",
            method="GET",
            params={
                "instance_id": instance_id,
                "client_id": client_id,
                "scope": scope,
                "redirect_url": redirect_url,
            },
            request_options=request_options,
        )
        try:
            if _response is None or not _response.text.strip():
                return AsyncHttpResponse(response=_response, data=None)
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.Optional[typing.Any],
                    parse_obj_as(
                        type_=typing.Optional[typing.Any],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ApiKeyAuth,
    CalcomOAuthErrorResponse,
    CalcomOAuthSuccessResponse,
    CallToolResponse,
    CallToolResult,
    ConnectionType,
    CreateSelfHostedServerResponse,
    CreateServerResponse,
    DeleteUserResponse,
    ExtendedMcpServer,
    ExternalServerInfo,
    ExternalServerRequest,
    GeneralAuth,
    GetAuthDataResponse,
    GetInstanceResponse,
    GetMcpServersResponse,
    GetOAuthUrlResponse,
    GetServerInstancesResponse,
    HttpValidationError,
    ListToolsResponse,
    McpServer,
    McpServerName,
    OAuthServerName,
    ServerTool,
    StatusResponse,
    StrataAddServersResponse,
    StrataCreateResponse,
    StrataDeleteServersResponse,
    StrataGetResponse,
    ToolFormat,
    ValidationError,
    ValidationErrorLocItem,
    WhiteLabelingResponse,
)
from .errors import BadRequestError, UnprocessableEntityError
from . import (
    airtable_oauth,
    asana_oauth,
    attio_oauth,
    box_oauth,
    calcom_oauth,
    canva_oauth,
    clickup_oauth,
    close_oauth,
    confluence_oauth,
    dialpad_oauth,
    docusign_oauth,
    dropbox_oauth,
    figma_oauth,
    gcalendar_oauth,
    gdocs_oauth,
    gdrive_oauth,
    github_oauth,
    gitlab_oauth,
    gmail_oauth,
    gsheets_oauth,
    hubspot_oauth,
    jira_oauth,
    klaviyo_oauth,
    linear_oauth,
    linkedin_oauth,
    mcp_server,
    notion_oauth,
    pagerduty_oauth,
    pipedrive_oauth,
    quickbooks_oauth,
    salesforce_oauth,
    slack_oauth,
    stripe_connect_oauth,
    supabase_oauth,
    user,
    vercel_oauth,
    white_labeling,
    wordpress_oauth,
    xero_oauth,
    zendesk_oauth,
)
from .client import AsyncKlavis, Klavis
from .environment import KlavisEnvironment
from .mcp_server import Authdata, DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem, Servers
from .version import __version__

__all__ = [
    "ApiKeyAuth",
    "AsyncKlavis",
    "Authdata",
    "BadRequestError",
    "CalcomOAuthErrorResponse",
    "CalcomOAuthSuccessResponse",
    "CallToolResponse",
    "CallToolResult",
    "ConnectionType",
    "CreateSelfHostedServerResponse",
    "CreateServerResponse",
    "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem",
    "DeleteUserResponse",
    "ExtendedMcpServer",
    "ExternalServerInfo",
    "ExternalServerRequest",
    "GeneralAuth",
    "GetAuthDataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetOAuthUrlResponse",
    "GetServerInstancesResponse",
    "HttpValidationError",
    "Klavis",
    "KlavisEnvironment",
    "ListToolsResponse",
    "McpServer",
    "McpServerName",
    "OAuthServerName",
    "ServerTool",
    "Servers",
    "StatusResponse",
    "StrataAddServersResponse",
    "StrataCreateResponse",
    "StrataDeleteServersResponse",
    "StrataGetResponse",
    "ToolFormat",
    "UnprocessableEntityError",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
    "__version__",
    "airtable_oauth",
    "asana_oauth",
    "attio_oauth",
    "box_oauth",
    "calcom_oauth",
    "canva_oauth",
    "clickup_oauth",
    "close_oauth",
    "confluence_oauth",
    "dialpad_oauth",
    "docusign_oauth",
    "dropbox_oauth",
    "figma_oauth",
    "gcalendar_oauth",
    "gdocs_oauth",
    "gdrive_oauth",
    "github_oauth",
    "gitlab_oauth",
    "gmail_oauth",
    "gsheets_oauth",
    "hubspot_oauth",
    "jira_oauth",
    "klaviyo_oauth",
    "linear_oauth",
    "linkedin_oauth",
    "mcp_server",
    "notion_oauth",
    "pagerduty_oauth",
    "pipedrive_oauth",
    "quickbooks_oauth",
    "salesforce_oauth",
    "slack_oauth",
    "stripe_connect_oauth",
    "supabase_oauth",
    "user",
    "vercel_oauth",
    "white_labeling",
    "wordpress_oauth",
    "xero_oauth",
    "zendesk_oauth",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .authdata import Authdata
from .delete_servers_from_strata_mcp_server_strata_strata_id_servers_delete_request_servers_item import (
    DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem,
)
from .servers import Servers

__all__ = ["Authdata", "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem", "Servers"]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.o_auth_server_name import OAuthServerName
from ..types.white_labeling_response import WhiteLabelingResponse
from .raw_client import AsyncRawWhiteLabelingClient, RawWhiteLabelingClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WhiteLabelingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWhiteLabelingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWhiteLabelingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWhiteLabelingClient
        """
        return self._raw_client

    def create_white_labeling(
        self,
        *,
        client_id: str,
        client_secret: str,
        server_name: OAuthServerName,
        callback_url: typing.Optional[str] = OMIT,
        account_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WhiteLabelingResponse:
        """
        Saves OAuth white labeling information, or updates existing information if the `client_id` matches.

        Parameters
        ----------
        client_id : str
            OAuth client ID

        client_secret : str
            OAuth client secret

        server_name : OAuthServerName
            Optional. The name of the server

        callback_url : typing.Optional[str]
            Optional. OAuth callback URL

        account_id : typing.Optional[str]
            Optional. The UUID of the account

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WhiteLabelingResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, OAuthServerName

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.white_labeling.create_white_labeling(
            client_id="client_id",
            client_secret="client_secret",
            server_name=OAuthServerName.AIRTABLE,
        )
        """
        _response = self._raw_client.create_white_labeling(
            client_id=client_id,
            client_secret=client_secret,
            server_name=server_name,
            callback_url=callback_url,
            account_id=account_id,
            request_options=request_options,
        )
        return _response.data

    def get_white_labeling_by_client_id(
        self, client_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> WhiteLabelingResponse:
        """
        Retrieves white labeling information for a specific OAuth client ID.

        Parameters
        ----------
        client_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WhiteLabelingResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.white_labeling.get_white_labeling_by_client_id(
            client_id="client_id",
        )
        """
        _response = self._raw_client.get_white_labeling_by_client_id(client_id, request_options=request_options)
        return _response.data


class AsyncWhiteLabelingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWhiteLabelingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWhiteLabelingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWhiteLabelingClient
        """
        return self._raw_client

    async def create_white_labeling(
        self,
        *,
        client_id: str,
        client_secret: str,
        server_name: OAuthServerName,
        callback_url: typing.Optional[str] = OMIT,
        account_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> WhiteLabelingResponse:
        """
        Saves OAuth white labeling information, or updates existing information if the `client_id` matches.

        Parameters
        ----------
        client_id : str
            OAuth client ID

        client_secret : str
            OAuth client secret

        server_name : OAuthServerName
            Optional. The name of the server

        callback_url : typing.Optional[str]
            Optional. OAuth callback URL

        account_id : typing.Optional[str]
            Optional. The UUID of the account

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WhiteLabelingResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, OAuthServerName

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.white_labeling.create_white_labeling(
                client_id="client_id",
                client_secret="client_secret",
                server_name=OAuthServerName.AIRTABLE,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_white_labeling(
            client_id=client_id,
            client_secret=client_secret,
            server_name=server_name,
            callback_url=callback_url,
            account_id=account_id,
            request_options=request_options,
        )
        return _response.data

    async def get_white_labeling_by_client_id(
        self, client_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> WhiteLabelingResponse:
        """
        Retrieves white labeling information for a specific OAuth client ID.

        Parameters
        ----------
        client_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        WhiteLabelingResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.white_labeling.get_white_labeling_by_client_id(
                client_id="client_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_white_labeling_by_client_id(client_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .airtable_oauth.client import AirtableOauthClient, AsyncAirtableOauthClient
from .asana_oauth.client import AsanaOauthClient, AsyncAsanaOauthClient
from .attio_oauth.client import AsyncAttioOauthClient, AttioOauthClient
from .box_oauth.client import AsyncBoxOauthClient, BoxOauthClient
from .calcom_oauth.client import AsyncCalcomOauthClient, CalcomOauthClient
from .canva_oauth.client import AsyncCanvaOauthClient, CanvaOauthClient
from .clickup_oauth.client import AsyncClickupOauthClient, ClickupOauthClient
from .close_oauth.client import AsyncCloseOauthClient, CloseOauthClient
from .confluence_oauth.client import AsyncConfluenceOauthClient, ConfluenceOauthClient
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .dialpad_oauth.client import AsyncDialpadOauthClient, DialpadOauthClient
from .docusign_oauth.client import AsyncDocusignOauthClient, DocusignOauthClient
from .dropbox_oauth.client import AsyncDropboxOauthClient, DropboxOauthClient
from .environment import KlavisEnvironment
from .figma_oauth.client import AsyncFigmaOauthClient, FigmaOauthClient
from .gcalendar_oauth.client import AsyncGcalendarOauthClient, GcalendarOauthClient
from .gdocs_oauth.client import AsyncGdocsOauthClient, GdocsOauthClient
from .gdrive_oauth.client import AsyncGdriveOauthClient, GdriveOauthClient
from .github_oauth.client import AsyncGithubOauthClient, GithubOauthClient
from .gitlab_oauth.client import AsyncGitlabOauthClient, GitlabOauthClient
from .gmail_oauth.client import AsyncGmailOauthClient, GmailOauthClient
from .gsheets_oauth.client import AsyncGsheetsOauthClient, GsheetsOauthClient
from .hubspot_oauth.client import AsyncHubspotOauthClient, HubspotOauthClient
from .jira_oauth.client import AsyncJiraOauthClient, JiraOauthClient
from .klaviyo_oauth.client import AsyncKlaviyoOauthClient, KlaviyoOauthClient
from .linear_oauth.client import AsyncLinearOauthClient, LinearOauthClient
from .linkedin_oauth.client import AsyncLinkedinOauthClient, LinkedinOauthClient
from .mcp_server.client import AsyncMcpServerClient, McpServerClient
from .notion_oauth.client import AsyncNotionOauthClient, NotionOauthClient
from .pagerduty_oauth.client import AsyncPagerdutyOauthClient, PagerdutyOauthClient
from .pipedrive_oauth.client import AsyncPipedriveOauthClient, PipedriveOauthClient
from .quickbooks_oauth.client import AsyncQuickbooksOauthClient, QuickbooksOauthClient
from .salesforce_oauth.client import AsyncSalesforceOauthClient, SalesforceOauthClient
from .slack_oauth.client import AsyncSlackOauthClient, SlackOauthClient
from .stripe_connect_oauth.client import AsyncStripeConnectOauthClient, StripeConnectOauthClient
from .supabase_oauth.client import AsyncSupabaseOauthClient, SupabaseOauthClient
from .user.client import AsyncUserClient, UserClient
from .vercel_oauth.client import AsyncVercelOauthClient, VercelOauthClient
from .white_labeling.client import AsyncWhiteLabelingClient, WhiteLabelingClient
from .wordpress_oauth.client import AsyncWordpressOauthClient, WordpressOauthClient
from .xero_oauth.client import AsyncXeroOauthClient, XeroOauthClient
from .zendesk_oauth.client import AsyncZendeskOauthClient, ZendeskOauthClient


class Klavis:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : KlavisEnvironment
        The environment to use for requests from the client. from .environment import KlavisEnvironment



        Defaults to KlavisEnvironment.DEFAULT



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from klavis import Klavis

    client = Klavis(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: KlavisEnvironment = KlavisEnvironment.DEFAULT,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.mcp_server = McpServerClient(client_wrapper=self._client_wrapper)
        self.white_labeling = WhiteLabelingClient(client_wrapper=self._client_wrapper)
        self.user = UserClient(client_wrapper=self._client_wrapper)
        self.slack_oauth = SlackOauthClient(client_wrapper=self._client_wrapper)
        self.github_oauth = GithubOauthClient(client_wrapper=self._client_wrapper)
        self.gitlab_oauth = GitlabOauthClient(client_wrapper=self._client_wrapper)
        self.supabase_oauth = SupabaseOauthClient(client_wrapper=self._client_wrapper)
        self.notion_oauth = NotionOauthClient(client_wrapper=self._client_wrapper)
        self.jira_oauth = JiraOauthClient(client_wrapper=self._client_wrapper)
        self.confluence_oauth = ConfluenceOauthClient(client_wrapper=self._client_wrapper)
        self.wordpress_oauth = WordpressOauthClient(client_wrapper=self._client_wrapper)
        self.gmail_oauth = GmailOauthClient(client_wrapper=self._client_wrapper)
        self.gdrive_oauth = GdriveOauthClient(client_wrapper=self._client_wrapper)
        self.gcalendar_oauth = GcalendarOauthClient(client_wrapper=self._client_wrapper)
        self.gsheets_oauth = GsheetsOauthClient(client_wrapper=self._client_wrapper)
        self.gdocs_oauth = GdocsOauthClient(client_wrapper=self._client_wrapper)
        self.attio_oauth = AttioOauthClient(client_wrapper=self._client_wrapper)
        self.salesforce_oauth = SalesforceOauthClient(client_wrapper=self._client_wrapper)
        self.asana_oauth = AsanaOauthClient(client_wrapper=self._client_wrapper)
        self.linear_oauth = LinearOauthClient(client_wrapper=self._client_wrapper)
        self.close_oauth = CloseOauthClient(client_wrapper=self._client_wrapper)
        self.clickup_oauth = ClickupOauthClient(client_wrapper=self._client_wrapper)
        self.airtable_oauth = AirtableOauthClient(client_wrapper=self._client_wrapper)
        self.hubspot_oauth = HubspotOauthClient(client_wrapper=self._client_wrapper)
        self.linkedin_oauth = LinkedinOauthClient(client_wrapper=self._client_wrapper)
        self.canva_oauth = CanvaOauthClient(client_wrapper=self._client_wrapper)
        self.xero_oauth = XeroOauthClient(client_wrapper=self._client_wrapper)
        self.dropbox_oauth = DropboxOauthClient(client_wrapper=self._client_wrapper)
        self.box_oauth = BoxOauthClient(client_wrapper=self._client_wrapper)
        self.quickbooks_oauth = QuickbooksOauthClient(client_wrapper=self._client_wrapper)
        self.zendesk_oauth = ZendeskOauthClient(client_wrapper=self._client_wrapper)
        self.stripe_connect_oauth = StripeConnectOauthClient(client_wrapper=self._client_wrapper)
        self.calcom_oauth = CalcomOauthClient(client_wrapper=self._client_wrapper)
        self.vercel_oauth = VercelOauthClient(client_wrapper=self._client_wrapper)
        self.pipedrive_oauth = PipedriveOauthClient(client_wrapper=self._client_wrapper)
        self.figma_oauth = FigmaOauthClient(client_wrapper=self._client_wrapper)
        self.klaviyo_oauth = KlaviyoOauthClient(client_wrapper=self._client_wrapper)
        self.pagerduty_oauth = PagerdutyOauthClient(client_wrapper=self._client_wrapper)
        self.docusign_oauth = DocusignOauthClient(client_wrapper=self._client_wrapper)
        self.dialpad_oauth = DialpadOauthClient(client_wrapper=self._client_wrapper)


class AsyncKlavis:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : KlavisEnvironment
        The environment to use for requests from the client. from .environment import KlavisEnvironment



        Defaults to KlavisEnvironment.DEFAULT



    api_key : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from klavis import AsyncKlavis

    client = AsyncKlavis(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: KlavisEnvironment = KlavisEnvironment.DEFAULT,
        api_key: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.mcp_server = AsyncMcpServerClient(client_wrapper=self._client_wrapper)
        self.white_labeling = AsyncWhiteLabelingClient(client_wrapper=self._client_wrapper)
        self.user = AsyncUserClient(client_wrapper=self._client_wrapper)
        self.slack_oauth = AsyncSlackOauthClient(client_wrapper=self._client_wrapper)
        self.github_oauth = AsyncGithubOauthClient(client_wrapper=self._client_wrapper)
        self.gitlab_oauth = AsyncGitlabOauthClient(client_wrapper=self._client_wrapper)
        self.supabase_oauth = AsyncSupabaseOauthClient(client_wrapper=self._client_wrapper)
        self.notion_oauth = AsyncNotionOauthClient(client_wrapper=self._client_wrapper)
        self.jira_oauth = AsyncJiraOauthClient(client_wrapper=self._client_wrapper)
        self.confluence_oauth = AsyncConfluenceOauthClient(client_wrapper=self._client_wrapper)
        self.wordpress_oauth = AsyncWordpressOauthClient(client_wrapper=self._client_wrapper)
        self.gmail_oauth = AsyncGmailOauthClient(client_wrapper=self._client_wrapper)
        self.gdrive_oauth = AsyncGdriveOauthClient(client_wrapper=self._client_wrapper)
        self.gcalendar_oauth = AsyncGcalendarOauthClient(client_wrapper=self._client_wrapper)
        self.gsheets_oauth = AsyncGsheetsOauthClient(client_wrapper=self._client_wrapper)
        self.gdocs_oauth = AsyncGdocsOauthClient(client_wrapper=self._client_wrapper)
        self.attio_oauth = AsyncAttioOauthClient(client_wrapper=self._client_wrapper)
        self.salesforce_oauth = AsyncSalesforceOauthClient(client_wrapper=self._client_wrapper)
        self.asana_oauth = AsyncAsanaOauthClient(client_wrapper=self._client_wrapper)
        self.linear_oauth = AsyncLinearOauthClient(client_wrapper=self._client_wrapper)
        self.close_oauth = AsyncCloseOauthClient(client_wrapper=self._client_wrapper)
        self.clickup_oauth = AsyncClickupOauthClient(client_wrapper=self._client_wrapper)
        self.airtable_oauth = AsyncAirtableOauthClient(client_wrapper=self._client_wrapper)
        self.hubspot_oauth = AsyncHubspotOauthClient(client_wrapper=self._client_wrapper)
        self.linkedin_oauth = AsyncLinkedinOauthClient(client_wrapper=self._client_wrapper)
        self.canva_oauth = AsyncCanvaOauthClient(client_wrapper=self._client_wrapper)
        self.xero_oauth = AsyncXeroOauthClient(client_wrapper=self._client_wrapper)
        self.dropbox_oauth = AsyncDropboxOauthClient(client_wrapper=self._client_wrapper)
        self.box_oauth = AsyncBoxOauthClient(client_wrapper=self._client_wrapper)
        self.quickbooks_oauth = AsyncQuickbooksOauthClient(client_wrapper=self._client_wrapper)
        self.zendesk_oauth = AsyncZendeskOauthClient(client_wrapper=self._client_wrapper)
        self.stripe_connect_oauth = AsyncStripeConnectOauthClient(client_wrapper=self._client_wrapper)
        self.calcom_oauth = AsyncCalcomOauthClient(client_wrapper=self._client_wrapper)
        self.vercel_oauth = AsyncVercelOauthClient(client_wrapper=self._client_wrapper)
        self.pipedrive_oauth = AsyncPipedriveOauthClient(client_wrapper=self._client_wrapper)
        self.figma_oauth = AsyncFigmaOauthClient(client_wrapper=self._client_wrapper)
        self.klaviyo_oauth = AsyncKlaviyoOauthClient(client_wrapper=self._client_wrapper)
        self.pagerduty_oauth = AsyncPagerdutyOauthClient(client_wrapper=self._client_wrapper)
        self.docusign_oauth = AsyncDocusignOauthClient(client_wrapper=self._client_wrapper)
        self.dialpad_oauth = AsyncDialpadOauthClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: KlavisEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.o_auth_server_name import OAuthServerName
from ..types.white_labeling_response import WhiteLabelingResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawWhiteLabelingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_white_labeling(
        self,
        *,
        client_id: str,
        client_secret: str,
        server_name: OAuthServerName,
        callback_url: typing.Optional[str] = OMIT,
        account_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[WhiteLabelingResponse]:
        """
        Saves OAuth white labeling information, or updates existing information if the `client_id` matches.

        Parameters
        ----------
        client_id : str
            OAuth client ID

        client_secret : str
            OAuth client secret

        server_name : OAuthServerName
            Optional. The name of the server

        callback_url : typing.Optional[str]
            Optional. OAuth callback URL

        account_id : typing.Optional[str]
            Optional. The UUID of the account

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[WhiteLabelingResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "white-labeling/create",
            method="POST",
            json={
                "client_id": client_id,
                "client_secret": client_secret,
                "server_name": server_name,
                "callback_url": callback_url,
                "account_id": account_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WhiteLabelingResponse,
                    parse_obj_as(
                        type_=WhiteLabelingResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_white_labeling_by_client_id(
        self, client_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[WhiteLabelingResponse]:
        """
        Retrieves white labeling information for a specific OAuth client ID.

        Parameters
        ----------
        client_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[WhiteLabelingResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"white-labeling/get/{jsonable_encoder(client_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WhiteLabelingResponse,
                    parse_obj_as(
                        type_=WhiteLabelingResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawWhiteLabelingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_white_labeling(
        self,
        *,
        client_id: str,
        client_secret: str,
        server_name: OAuthServerName,
        callback_url: typing.Optional[str] = OMIT,
        account_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[WhiteLabelingResponse]:
        """
        Saves OAuth white labeling information, or updates existing information if the `client_id` matches.

        Parameters
        ----------
        client_id : str
            OAuth client ID

        client_secret : str
            OAuth client secret

        server_name : OAuthServerName
            Optional. The name of the server

        callback_url : typing.Optional[str]
            Optional. OAuth callback URL

        account_id : typing.Optional[str]
            Optional. The UUID of the account

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[WhiteLabelingResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "white-labeling/create",
            method="POST",
            json={
                "client_id": client_id,
                "client_secret": client_secret,
                "server_name": server_name,
                "callback_url": callback_url,
                "account_id": account_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WhiteLabelingResponse,
                    parse_obj_as(
                        type_=WhiteLabelingResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_white_labeling_by_client_id(
        self, client_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[WhiteLabelingResponse]:
        """
        Retrieves white labeling information for a specific OAuth client ID.

        Parameters
        ----------
        client_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[WhiteLabelingResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"white-labeling/get/{jsonable_encoder(client_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WhiteLabelingResponse,
                    parse_obj_as(
                        type_=WhiteLabelingResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .tool_format import ToolFormat


class ListToolsResponse(UniversalBaseModel):
    success: bool = pydantic.Field()
    """
    Whether the list tools request was successful
    """

    tools: typing.Optional[typing.List[typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    List of tools in the requested format
    """

    format: ToolFormat = pydantic.Field()
    """
    The format of the returned tools
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error message, if the request failed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.mcp_server_name import McpServerName

Servers = typing.Union[typing.List[McpServerName], typing.Literal["ALL"]]
